pub struct Refund {
pub amount: Option<i32>,
pub business_id: String,
pub created_at: String,
pub currency: Option<Currency>,
pub customer: Box<CustomerLimitedDetailsResponse>,
pub is_partial: bool,
pub metadata: HashMap<String, String>,
pub payment_id: String,
pub reason: Option<String>,
pub refund_id: String,
pub status: RefundStatus,
pub payload_type: PayloadType,
}Fields
amount: Option<i32>The refunded amount.
business_id: StringThe unique identifier of the business issuing the refund.
created_at: StringThe timestamp of when the refund was created in UTC.
currency: Option<Currency>The currency of the refund, represented as an ISO 4217 currency code.
customer: Box<CustomerLimitedDetailsResponse>Details about the customer for this refund (from the associated payment)
is_partial: boolIf true the refund is a partial refund
metadata: HashMap<String, String>Additional metadata stored with the refund.
payment_id: StringThe unique identifier of the payment associated with the refund.
reason: Option<String>The reason provided for the refund, if any. Optional.
refund_id: StringThe unique identifier of the refund.
status: RefundStatusThe current status of the refund.
payload_type: PayloadTypeImplementations