pub struct CreateProductRequest {Show 13 fields
pub addons: Option<Vec<String>>,
pub brand_id: Option<String>,
pub credit_entitlements: Option<Vec<AttachCreditEntitlementRequest>>,
pub description: Option<String>,
pub digital_product_delivery: Option<Box<CreateDigitalProductDeliveryRequest>>,
pub license_key_activation_message: Option<String>,
pub license_key_activations_limit: Option<i32>,
pub license_key_duration: Option<Box<LicenseKeyDuration>>,
pub license_key_enabled: Option<bool>,
pub metadata: Option<HashMap<String, String>>,
pub name: String,
pub price: Box<Price>,
pub tax_category: TaxCategory,
}Fields
addons: Option<Vec<String>>Addons available for subscription product
brand_id: Option<String>Brand id for the product, if not provided will default to primary brand
credit_entitlements: Option<Vec<AttachCreditEntitlementRequest>>Optional credit entitlements to attach (max 3)
description: Option<String>Optional description of the product
digital_product_delivery: Option<Box<CreateDigitalProductDeliveryRequest>>Choose how you would like you digital product delivered
license_key_activation_message: Option<String>Optional message displayed during license key activation
license_key_activations_limit: Option<i32>The number of times the license key can be activated. Must be 0 or greater
license_key_duration: Option<Box<LicenseKeyDuration>>Duration configuration for the license key. Set to null if you don’t want the license key to expire. For subscriptions, the lifetime of the license key is tied to the subscription period
license_key_enabled: Option<bool>When true, generates and sends a license key to your customer. Defaults to false
metadata: Option<HashMap<String, String>>Additional metadata for the product
name: StringName of the product
price: Box<Price>Price configuration for the product
tax_category: TaxCategoryTax category applied to this product
Implementations
Sourceimpl CreateProductRequest
impl CreateProductRequest
pub fn new( name: String, price: Price, tax_category: TaxCategory, ) -> CreateProductRequest